# -*- coding: utf-8 -*-
from setuphelpers import *
import os
import sys


ext_lib_dir = os.sep.join([sys.executable.rsplit(os.path.sep, 1)[0].replace("/bin", "").replace("\\Scripts", ""), "libdev"])
if sys.platform == "win32":
    waptpython_lib_sp_dir = os.sep.join([sys.executable.rsplit(os.path.sep, 1)[0].replace("\\Scripts", ""), "lib", "site-packages"])
else:
    waptpython_lib_sp_dir = os.sep.join([sys.executable.rsplit(os.path.sep, 1)[0].replace("/bin", "/lib/python3.8"), "site-packages"])


package_name = "pip"
install_in_ext_lib = False


def install():
    bin_name = glob.glob(f"{package_name}/{package_name}-*.whl")[0]
    for lib_dir in glob.glob(f"{ext_lib_dir}/{package_name}*/"):
        remove_tree(lib_dir)
    if install_in_ext_lib:
        mkdirs(ext_lib_dir)
        unzip(bin_name, ext_lib_dir)
    else:
        for lib_dir in glob.glob(f"{waptpython_lib_sp_dir}/{package_name}*/"):
            remove_tree(lib_dir)
        unzip(bin_name, waptpython_lib_sp_dir)


def audit():
    audit_status = "OK"
    if install_in_ext_lib:
        if glob.glob(f"{ext_lib_dir}/{package_name}-{control.get_software_version()}.dist-info/*"):
            print(f"{control.package} is installed and up-to-date.")
        elif glob.glob(f"{ext_lib_dir}/{package_name}/*"):
            print(f"{control.package} is installed in another version.")
        else:
            print(f"{control.package} is not installed.")
            print(f"Reinstalling: {control.package}")
            WAPT.install(control.package, force=True)
            audit_status = "WARNING"
    else:
        pip_show_cmd = str(run(f'"{get_waptpython_path()}" -m pip show {package_name}', accept_returncodes=[0, 1, 3010])).strip()
        print(pip_show_cmd)
        if "No module named pip" in pip_show_cmd:
            pip_package = control.package.split("-")[0] + "-waptpython-pip"
            print(f"Reinstalling: {pip_package}")
            WAPT.install(control.package.split("-")[0] + "-waptpython-wheel", force=True)
            WAPT.audit(control.package.split("-")[0] + "-waptpython-wheel", force=True)
            WAPT.install(pip_package, force=True)
            WAPT.audit(pip_package, force=True)
            audit_status = "WARNING"

    return audit_status


def uninstall():
    if install_in_ext_lib:
        for lib_dir in glob.glob(f"{ext_lib_dir}/{package_name}*/"):
            remove_tree(lib_dir)
    else:
        # pip_uninstall_cmd = f'"{get_waptpython_path()}" -m pip uninstall {package_name} -y'
        # print(run(pip_uninstall_cmd))
        for lib_dir in glob.glob(f"{waptpython_lib_sp_dir}/{package_name}*/"):
            remove_tree(lib_dir)


def get_waptpython_path():
    if get_os_name() == "Windows":
        return makepath(WAPT.wapt_base_dir, "waptpython.exe")
    else:
        return makepath(WAPT.wapt_base_dir, "waptpython.sh")
